@@ -123,9 +123,9 @@ class OdooConnection:
         if len(calculated_field_id) == 0:
             REPORT_CALC.create(value_dict)
         else:
-            calculated_field_id = calculated_field_id[0]
-            calculated_field_object = REPORT_CALC.browse(calculated_field_id)
-            calculated_field_object.write(value_dict)
+            # calculated_field_id = calculated_field_id[0]
+            # calculated_field_object = REPORT_CALC.browse(calculated_field_id)
+            REPORT_CALC.write(calculated_field_id, value_dict)
 
     def _search_report(self, model_name, report_name):
         """
@@ -136,7 +136,8 @@ class OdooConnection:
         """
         IR_ACTIONS_REPORT = self.connection.env['ir.actions.report']
         report_ids = IR_ACTIONS_REPORT.search(
-            [('model', '=', model_name), '|', ('name', '=ilike', report_name), ('name', '=ilike', report_name + " " + "(PDF)")])
+            [('model', '=', model_name), '|', ('name', '=ilike', report_name),
+             ('name', '=ilike', report_name + " " + "(PDF)")])
         if len(report_ids) == 0:
             return False
         else:
@@ -184,3 +185,13 @@ class OdooConnection:
                 if not dependency_installed:
                     return False
         return True
+
+    def disable_qweb(self):
+        IR_ACTIONS_REPORT = self.connection.env['ir.actions.report']
+        report_ids = IR_ACTIONS_REPORT.search(
+            ['|', ('report_type', '=', 'qweb-pdf'), '|', ('report_type', '=', 'qweb-html'),
+             ('report_type', '=', 'qweb-text')])
+        for report_id in report_ids:
+            report_object = IR_ACTIONS_REPORT.browse(report_id)
+            report_object.unlink_action()
+        print("Disabled QWeb for " + self.database)
